@@ -5,7 +5,7 @@
 ** in the input file. */
 #include "first.h"
 #include <stdio.h>
-#line 5 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 5 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 
 #include "first.h"
 #include "base.h"
@@ -771,42 +771,42 @@ static void yy_destructor(YYCODETYPE yymajor, YYMINORTYPE *yypminor){
     case 26:
     case 27:
     case 28:
-#line 377 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 377 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 { buffer_free((yypminor->yy0)); }
 #line 776 "./configparser.c"
       break;
     case 38:
-#line 368 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 368 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 { if ((yypminor->yy59)) (yypminor->yy59)->fn->free((yypminor->yy59)); }
 #line 781 "./configparser.c"
       break;
     case 39:
-#line 369 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 369 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 { if ((yypminor->yy59)) (yypminor->yy59)->fn->free((yypminor->yy59)); }
 #line 786 "./configparser.c"
       break;
     case 40:
-#line 370 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 370 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 { if ((yypminor->yy59)) (yypminor->yy59)->fn->free((yypminor->yy59)); }
 #line 791 "./configparser.c"
       break;
     case 43:
-#line 371 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 371 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 { array_free((yypminor->yy38)); }
 #line 796 "./configparser.c"
       break;
     case 44:
-#line 372 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 372 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 { array_free((yypminor->yy38)); }
 #line 801 "./configparser.c"
       break;
     case 45:
-#line 373 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 373 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 { buffer_free((yypminor->yy9)); }
 #line 806 "./configparser.c"
       break;
     case 46:
-#line 374 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 374 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 { buffer_free((yypminor->yy9)); }
 #line 811 "./configparser.c"
       break;
@@ -1087,7 +1087,7 @@ static void yy_reduce(
         /* No destructor defined for global */
         break;
       case 5:
-#line 350 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 350 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 { yymsp[-1].minor.yy18 = NULL; }
 #line 1092 "./configparser.c"
   yy_destructor(1,&yymsp[0].minor);
@@ -1102,7 +1102,7 @@ static void yy_reduce(
   yy_destructor(1,&yymsp[0].minor);
         break;
       case 9:
-#line 379 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 379 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   if (ctx->ok) {
     buffer_copy_buffer(&yymsp[0].minor.yy59->key, yymsp[-2].minor.yy9);
@@ -1130,7 +1130,7 @@ static void yy_reduce(
   yy_destructor(2,&yymsp[-1].minor);
         break;
       case 10:
-#line 403 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 403 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   if (ctx->ok) {
     if (strncmp(yymsp[-2].minor.yy9->ptr, "env.", sizeof("env.") - 1) == 0) {
@@ -1153,7 +1153,7 @@ static void yy_reduce(
   yy_destructor(3,&yymsp[-1].minor);
         break;
       case 11:
-#line 422 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 422 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   if (ctx->ok) {
     array *vars = ctx->current->value;
@@ -1188,7 +1188,7 @@ static void yy_reduce(
   yy_destructor(4,&yymsp[-1].minor);
         break;
       case 12:
-#line 453 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 453 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   if (strchr(yymsp[0].minor.yy0->ptr, '.') == NULL) {
     buffer_copy_string((yygotominor.yy9 = buffer_init()), "var.");
@@ -1203,7 +1203,7 @@ static void yy_reduce(
 #line 1203 "./configparser.c"
         break;
       case 13:
-#line 465 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 465 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy59 = NULL;
   if (ctx->ok) {
@@ -1222,7 +1222,7 @@ static void yy_reduce(
   yy_destructor(6,&yymsp[-1].minor);
         break;
       case 14:
-#line 480 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 480 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy59 = yymsp[0].minor.yy59;
   yymsp[0].minor.yy59 = NULL;
@@ -1230,7 +1230,7 @@ static void yy_reduce(
 #line 1230 "./configparser.c"
         break;
       case 15:
-#line 485 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 485 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy59 = NULL;
   if (ctx->ok) {
@@ -1258,7 +1258,7 @@ static void yy_reduce(
 #line 1258 "./configparser.c"
         break;
       case 16:
-#line 510 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 510 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy59 = (data_unset *)array_data_string_init();
   /* assumes array_data_string_init() result does not need swap, buffer_free()*/
@@ -1269,7 +1269,7 @@ static void yy_reduce(
 #line 1269 "./configparser.c"
         break;
       case 17:
-#line 518 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 518 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   char *endptr;
   yygotominor.yy59 = (data_unset *)array_data_integer_init();
@@ -1287,7 +1287,7 @@ static void yy_reduce(
 #line 1287 "./configparser.c"
         break;
       case 18:
-#line 532 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 532 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy59 = (data_unset *)array_data_array_init();
   /* assumes array_data_array_init() result does not need swap, array_free() */
@@ -1298,7 +1298,7 @@ static void yy_reduce(
 #line 1298 "./configparser.c"
         break;
       case 19:
-#line 539 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 539 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy38 = array_init(8);
 }
@@ -1307,7 +1307,7 @@ static void yy_reduce(
   yy_destructor(10,&yymsp[0].minor);
         break;
       case 20:
-#line 542 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 542 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy38 = yymsp[-1].minor.yy38;
   yymsp[-1].minor.yy38 = NULL;
@@ -1317,7 +1317,7 @@ static void yy_reduce(
   yy_destructor(10,&yymsp[0].minor);
         break;
       case 21:
-#line 547 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 547 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy38 = NULL;
   if (ctx->ok) {
@@ -1343,7 +1343,7 @@ static void yy_reduce(
   yy_destructor(11,&yymsp[-1].minor);
         break;
       case 22:
-#line 569 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 569 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy38 = yymsp[-1].minor.yy38;
   yymsp[-1].minor.yy38 = NULL;
@@ -1352,7 +1352,7 @@ static void yy_reduce(
   yy_destructor(11,&yymsp[0].minor);
         break;
       case 23:
-#line 574 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 574 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy38 = NULL;
   if (ctx->ok) {
@@ -1366,7 +1366,7 @@ static void yy_reduce(
 #line 1366 "./configparser.c"
         break;
       case 24:
-#line 585 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 585 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy59 = yymsp[0].minor.yy59;
   yymsp[0].minor.yy59 = NULL;
@@ -1374,7 +1374,7 @@ static void yy_reduce(
 #line 1374 "./configparser.c"
         break;
       case 25:
-#line 589 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 589 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy59 = NULL;
   if (ctx->ok) {
@@ -1397,7 +1397,7 @@ static void yy_reduce(
       case 27:
         break;
       case 28:
-#line 606 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 606 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   data_config *dc;
   dc = configparser_get_data_config(ctx->srv->config_context, CONST_STR_LEN("global"));
@@ -1408,7 +1408,7 @@ static void yy_reduce(
   yy_destructor(13,&yymsp[0].minor);
         break;
       case 29:
-#line 613 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 613 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   configparser_pop(ctx);
 }
@@ -1419,7 +1419,7 @@ static void yy_reduce(
   yy_destructor(15,&yymsp[0].minor);
         break;
       case 30:
-#line 617 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 617 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy18 = NULL;
   if (ctx->ok) {
@@ -1443,7 +1443,7 @@ static void yy_reduce(
   yy_destructor(16,&yymsp[-1].minor);
         break;
       case 31:
-#line 636 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 636 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy18 = NULL;
   if (ctx->ok) {
@@ -1518,7 +1518,7 @@ static void yy_reduce(
   yy_destructor(16,&yymsp[-1].minor);
         break;
       case 32:
-#line 706 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 706 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy18 = yymsp[0].minor.yy18;
   yymsp[0].minor.yy18 = NULL;
@@ -1526,7 +1526,7 @@ static void yy_reduce(
 #line 1526 "./configparser.c"
         break;
       case 33:
-#line 711 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 711 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy18 = NULL;
   if (ctx->ok) {
@@ -1540,7 +1540,7 @@ static void yy_reduce(
   yy_destructor(15,&yymsp[0].minor);
         break;
       case 34:
-#line 718 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 718 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy18 = NULL;
   if (ctx->ok) {
@@ -1554,7 +1554,7 @@ static void yy_reduce(
   yy_destructor(15,&yymsp[0].minor);
         break;
       case 35:
-#line 725 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 725 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
 
   if (ctx->ok && yymsp[0].minor.yy59->type != TYPE_STRING) {
@@ -1579,7 +1579,7 @@ static void yy_reduce(
   yy_destructor(20,&yymsp[-2].minor);
         break;
       case 36:
-#line 744 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 744 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   if (ctx->ok) {
     configparser_parse_else_condition(ctx);
@@ -1588,7 +1588,7 @@ static void yy_reduce(
 #line 1588 "./configparser.c"
         break;
       case 37:
-#line 750 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 750 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy69 = CONFIG_COND_EQ;
 }
@@ -1596,7 +1596,7 @@ static void yy_reduce(
   yy_destructor(21,&yymsp[0].minor);
         break;
       case 38:
-#line 753 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 753 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy69 = CONFIG_COND_MATCH;
 }
@@ -1604,7 +1604,7 @@ static void yy_reduce(
   yy_destructor(22,&yymsp[0].minor);
         break;
       case 39:
-#line 756 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 756 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy69 = CONFIG_COND_NE;
 }
@@ -1612,7 +1612,7 @@ static void yy_reduce(
   yy_destructor(23,&yymsp[0].minor);
         break;
       case 40:
-#line 759 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 759 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy69 = CONFIG_COND_NOMATCH;
 }
@@ -1620,7 +1620,7 @@ static void yy_reduce(
   yy_destructor(24,&yymsp[0].minor);
         break;
       case 41:
-#line 762 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 762 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy69 = CONFIG_COND_PREFIX;
 }
@@ -1628,7 +1628,7 @@ static void yy_reduce(
   yy_destructor(25,&yymsp[0].minor);
         break;
       case 42:
-#line 765 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 765 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy69 = CONFIG_COND_SUFFIX;
 }
@@ -1636,7 +1636,7 @@ static void yy_reduce(
   yy_destructor(26,&yymsp[0].minor);
         break;
       case 43:
-#line 769 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 769 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   yygotominor.yy9 = NULL;
   if (ctx->ok) {
@@ -1656,7 +1656,7 @@ static void yy_reduce(
 #line 1656 "./configparser.c"
         break;
       case 44:
-#line 786 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 786 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   if (ctx->ok) {
     if (0 != config_parse_file(ctx->srv, ctx, yymsp[0].minor.yy9->ptr)) {
@@ -1670,7 +1670,7 @@ static void yy_reduce(
   yy_destructor(27,&yymsp[-1].minor);
         break;
       case 45:
-#line 796 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 796 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 {
   if (ctx->ok) {
     if (0 != config_parse_cmd(ctx->srv, ctx, yymsp[0].minor.yy9->ptr)) {
@@ -1710,7 +1710,7 @@ static void yy_parse_failed(
   while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will be executed whenever the
   ** parser fails */
-#line 341 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.65-1.x86_64/src/lighttpd-1.4.65/src/configparser.y"
+#line 341 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.66-1.i686/src/lighttpd-1.4.66/src/configparser.y"
 
   ctx->ok = 0;
 
